const signatures = require('sodium-signatures')
const encryption = require('sodium-encryption')
const ed2curve = require('ed2curve')
const bufferJSON = require('buffer-json')

// service and user are ed25519 key pair generated by signatures.keyPair()

function msg (sender, receiver, payload) {
  payload = Buffer(payload)
  var sig = signatures.sign(payload, sender.secretKey)
  var nonce = encryption.nonce()

  var sharedKey = encryption.scalarMultiplication(ed2curve.convertSecretKey(sender.secretKey), ed2curve.convertPublicKey(receiver.publicKey))

  return {
    nonce,
    payload: encryption.encrypt(Buffer(sign(sig, payload)), nonce, sharedKey)
  }
}

function openMsg (sender, receiver, msg) {
  var sharedKey = encryption.scalarMultiplication(
    ed2curve.convertSecretKey(receiver.secretKey),
    ed2curve.convertPublicKey(sender.publicKey))
  var decrypted = encryption.decrypt(msg.payload, msg.nonce, sharedKey)
  if (!decrypted) return null

  decrypted = JSON.parse(decrypted, bufferJSON.reviver)

  if (!signatures.verify(decrypted.payload, decrypted.sig, sender.publicKey)) return null

  return decrypted.payload
}

module.exports = {msg, openMsg}

function sign (sig, payload) {
  return Buffer(JSON.stringify({sig: sig, payload: payload}, bufferJSON.replacer))
}
